==> jc-1.4.0.tar.gz: java/awt/DisplayMode.h <==
// public final class java.awt.DisplayMode

// class file dependencies
// @dep_class 487a1f9d4b044a12 java_awt_DisplayMode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_DisplayMode_H_
#define _JC_java_awt_DisplayMode_H_

// Forward structure declarations
struct _jc_java_awt_DisplayMode$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_DisplayMode$sub_refs	_jc_java_awt_DisplayMode$sub_refs;
typedef struct _jc_java_awt_DisplayMode$sub_nonrefs	_jc_java_awt_DisplayMode$sub_nonrefs;
typedef struct _jc_java_awt_DisplayMode$refs	_jc_java_awt_DisplayMode$refs;
typedef struct _jc_java_awt_DisplayMode$nonrefs	_jc_java_awt_DisplayMode$nonrefs;
typedef struct _jc_java_awt_DisplayMode$object	_jc_java_awt_DisplayMode$object;

typedef struct _jc_java_awt_DisplayMode$fields_struct	_jc_java_awt_DisplayMode$fields_struct;
typedef const struct _jc_java_awt_DisplayMode$vmethods	_jc_java_awt_DisplayMode$vmethods;
typedef const struct _jc_java_awt_DisplayMode$vtable	_jc_java_awt_DisplayMode$vtable;
typedef const struct _jc_java_awt_DisplayMode$vtype	_jc_java_awt_DisplayMode$vtype;

// Class fields structure
struct _jc_java_awt_DisplayMode$fields_struct {
	jint	BIT__5fDEPTH__5fMULTI;
	jint	REFRESH__5fRATE__5fUNKNOWN;
};
extern _jc_java_awt_DisplayMode$fields_struct _jc_java_awt_DisplayMode$class_fields;

// Constructors
extern void _jc_java_awt_DisplayMode$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_awt_DisplayMode$object *, jint, jint, jint, jint);

// Virtual methods
extern jboolean _jc_java_awt_DisplayMode$method$equals$1243c3299a067c9f(_jc_env *, struct _jc_java_awt_DisplayMode$object *, struct _jc_java_awt_DisplayMode$object *);
extern jint _jc_java_awt_DisplayMode$method$getBitDepth$eddb5c0637fcd41b(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
extern jint _jc_java_awt_DisplayMode$method$getHeight$68727004cbd10139(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
extern jint _jc_java_awt_DisplayMode$method$getRefreshRate$8ceb0849a0883903(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
extern jint _jc_java_awt_DisplayMode$method$getWidth$0d702aea89749e0c(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
extern jint _jc_java_awt_DisplayMode$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_DisplayMode$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_DisplayMode$method_info$equals$1243c3299a067c9f;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getBitDepth$eddb5c0637fcd41b;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getHeight$68727004cbd10139;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getRefreshRate$8ceb0849a0883903;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getWidth$0d702aea89749e0c;
extern _jc_method _jc_java_awt_DisplayMode$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_awt_DisplayMode$vmethods {
	jboolean	(*equals$1243c3299a067c9f)(_jc_env *, struct _jc_java_awt_DisplayMode$object *, struct _jc_java_awt_DisplayMode$object *);
	jint	(*getBitDepth$eddb5c0637fcd41b)(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
	jint	(*getHeight$68727004cbd10139)(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
	jint	(*getRefreshRate$8ceb0849a0883903)(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
	jint	(*getWidth$0d702aea89749e0c)(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_DisplayMode$object *);
};

// Vtable
struct _jc_java_awt_DisplayMode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_DisplayMode$vmethods	java_awt_DisplayMode;
};

// Vtype
struct _jc_java_awt_DisplayMode$vtype {
	_jc_type			type;
	_jc_java_awt_DisplayMode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_DisplayMode$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_DisplayMode$refs {
    _jc_java_awt_DisplayMode$sub_refs	java_awt_DisplayMode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_DisplayMode$sub_nonrefs {
	jint	width;
	jint	height;
	jint	bitDepth;
	jint	refreshRate;
};

// Non-reference instance fields (object)
struct _jc_java_awt_DisplayMode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_DisplayMode$sub_nonrefs	java_awt_DisplayMode;
};

// Object instance structure
struct _jc_java_awt_DisplayMode$object {
	_jc_java_awt_DisplayMode$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_DisplayMode$vtype	*vtype;
	_jc_java_awt_DisplayMode$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_DisplayMode$vtype _jc_java_awt_DisplayMode$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_DisplayMode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_DisplayMode$class_object;

#endif	/* _JC_java_awt_DisplayMode_H_ */

==> jc-1.4.6.tar.gz: java/awt/DisplayMode.h <==
// public final class java.awt.DisplayMode

// class file dependencies
// @dep_class 487a1f9d4b044a12 java_awt_DisplayMode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_DisplayMode_H_
#define _JC_java_awt_DisplayMode_H_

// Forward structure declarations
struct _jc_java_awt_DisplayMode$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_DisplayMode$sub_refs	_jc_java_awt_DisplayMode$sub_refs;
typedef struct _jc_java_awt_DisplayMode$sub_nonrefs	_jc_java_awt_DisplayMode$sub_nonrefs;
typedef struct _jc_java_awt_DisplayMode$refs	_jc_java_awt_DisplayMode$refs;
typedef struct _jc_java_awt_DisplayMode$nonrefs	_jc_java_awt_DisplayMode$nonrefs;
typedef struct _jc_java_awt_DisplayMode$object	_jc_java_awt_DisplayMode$object;

typedef struct _jc_java_awt_DisplayMode$fields_struct	_jc_java_awt_DisplayMode$fields_struct;
typedef const struct _jc_java_awt_DisplayMode$vmethods	_jc_java_awt_DisplayMode$vmethods;
typedef const struct _jc_java_awt_DisplayMode$vtable	_jc_java_awt_DisplayMode$vtable;
typedef const struct _jc_java_awt_DisplayMode$vtype	_jc_java_awt_DisplayMode$vtype;

// Class fields structure
struct _jc_java_awt_DisplayMode$fields_struct {
	jint	BIT__5fDEPTH__5fMULTI;
	jint	REFRESH__5fRATE__5fUNKNOWN;
};
extern _jc_java_awt_DisplayMode$fields_struct _jc_java_awt_DisplayMode$class_fields;

// Constructors
extern void _jc_java_awt_DisplayMode$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_awt_DisplayMode$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_DisplayMode$method$equals$1243c3299a067c9f(_jc_env *, struct _jc_java_awt_DisplayMode$object *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_DisplayMode$method$getBitDepth$eddb5c0637fcd41b(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_DisplayMode$method$getHeight$68727004cbd10139(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_DisplayMode$method$getRefreshRate$8ceb0849a0883903(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_DisplayMode$method$getWidth$0d702aea89749e0c(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_DisplayMode$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_DisplayMode$method_info$equals$1243c3299a067c9f;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getBitDepth$eddb5c0637fcd41b;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getHeight$68727004cbd10139;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getRefreshRate$8ceb0849a0883903;
extern _jc_method _jc_java_awt_DisplayMode$method_info$getWidth$0d702aea89749e0c;
extern _jc_method _jc_java_awt_DisplayMode$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_awt_DisplayMode$vmethods {
	jboolean	(*equals$1243c3299a067c9f)(_jc_env *, struct _jc_java_awt_DisplayMode$object *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
	jint	(*getBitDepth$eddb5c0637fcd41b)(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
	jint	(*getHeight$68727004cbd10139)(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
	jint	(*getRefreshRate$8ceb0849a0883903)(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
	jint	(*getWidth$0d702aea89749e0c)(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_DisplayMode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_DisplayMode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_DisplayMode$vmethods	java_awt_DisplayMode;
};

// Vtype
struct _jc_java_awt_DisplayMode$vtype {
	_jc_type			type;
	_jc_java_awt_DisplayMode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_DisplayMode$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_DisplayMode$refs {
    _jc_java_awt_DisplayMode$sub_refs	java_awt_DisplayMode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_DisplayMode$sub_nonrefs {
	jint	width;
	jint	height;
	jint	bitDepth;
	jint	refreshRate;
};

// Non-reference instance fields (object)
struct _jc_java_awt_DisplayMode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_DisplayMode$sub_nonrefs	java_awt_DisplayMode;
};

// Object instance structure
struct _jc_java_awt_DisplayMode$object {
	_jc_java_awt_DisplayMode$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_DisplayMode$vtype	*vtype;
	_jc_java_awt_DisplayMode$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_DisplayMode$vtype _jc_java_awt_DisplayMode$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_DisplayMode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_DisplayMode$class_object;

#endif	/* _JC_java_awt_DisplayMode_H_ */
